@@ -1,14 +1,18 @@
 import os
 import sys
 import time
+from datetime import datetime as Datetime
 from typing import Optional
 
+import pytz
 import typer
+from colorama import Fore
 
 from . import (copy, getPath, makeFolder, makeTempWorkspace, readFile, remove,
                writeFile)
 from .byte import decode
 from .execute import execute
+from .print import printColor
 from .zip import zipFileExtract
 
 app = typer.Typer()
@@ -40,24 +44,24 @@ def exit(errorMsg: str):
 @app.command(
     help="创建 beniutils.task 项目",
 )
-def task_create(
-    targetPath: Optional[str] = typer.Argument("", help="指定项目路径，默认在当前系统路径", show_default=False),
+def taskCreate(
+    folder: str = typer.Argument("", help="指定项目路径，默认在当前系统路径", show_default=False),
 ):
-    targetPath = targetPath or os.getcwd()
-    makeFolder(targetPath)
+    folder = folder or os.getcwd()
+    makeFolder(folder)
     workspaceFolder = makeTempWorkspace()
     try:
         taskCreateZipFile = getPath(os.path.dirname(__file__), "data/task_create.zip")
         zipFileExtract(taskCreateZipFile, workspaceFolder)
         for fileName in os.listdir(workspaceFolder):
-            toFile = getPath(targetPath, fileName)
+            toFile = getPath(folder, fileName)
             if os.path.exists(toFile):
                 raise Exception(f"创建失败，指定路径下已存在 {toFile}")
         for fileName in os.listdir(workspaceFolder):
             fromFile = getPath(workspaceFolder, fileName)
-            toFile = getPath(targetPath, fileName)
+            toFile = getPath(folder, fileName)
             copy(fromFile, toFile)
-        print("创建项目成功 " + targetPath)
+        print("创建项目成功 " + folder)
     finally:
         remove(workspaceFolder)
 
@@ -65,28 +69,28 @@ def task_create(
 @app.command(
     help="发布 beniutils.task 项目",
 )
-def task_build(
-    targetPath: Optional[str] = typer.Argument("", help="指定项目路径，默认在当前系统路径", show_default=False),
+def taskBuild(
+    folder: str = typer.Argument("", help="指定项目路径，默认在当前系统路径", show_default=False),
 ):
     currentPath: str = ""
     workspaceFolder: str = ""
     try:
         currentPath = os.getcwd()
-        targetPath = targetPath or currentPath
+        folder = folder or currentPath
         workspaceFolder = makeTempWorkspace()
         ignoreList = ["main.py"]
-        mainPyFile = getPath(targetPath, "project/src/main.py")
+        mainPyFile = getPath(folder, "project/src/main.py")
         if not os.path.isfile(mainPyFile):
             exit(f"发布失败，主文件不存在 {mainPyFile}")
         hiddenimports = [x[:-3] for x in os.listdir(os.path.dirname(mainPyFile)) if x.endswith(".py") and x not in ignoreList]
         name = "task"
         icon = getPath(workspaceFolder, "task.ico")
-        pathex = getPath(targetPath, "project")
+        pathex = getPath(folder, "project")
         taskBuildZipFile = getPath(os.path.dirname(__file__), "data/task_build.zip")
         zipFileExtract(taskBuildZipFile, workspaceFolder)
         taskSpecFile = getPath(workspaceFolder, "task.spec")
         taskSpecContent = readFile(taskSpecFile)
-        taskSpecContent = taskSpecContent.replace("<<projectSrcPath>>", getPath(targetPath, "project/src"))
+        taskSpecContent = taskSpecContent.replace("<<projectSrcPath>>", getPath(folder, "project/src"))
         taskSpecContent = taskSpecContent.replace("<<mainPyFile>>", mainPyFile)
         taskSpecContent = taskSpecContent.replace("<<pathex>>", pathex)
         taskSpecContent = taskSpecContent.replace("<<hiddenimports>>", ",".join([f'"{x}"' for x in hiddenimports]))
@@ -110,7 +114,7 @@ def task_build(
         print(executeLog)
 
         fromExeFile = getPath(workspaceFolder, f"dist/{name}.exe")
-        toExeFile = getPath(targetPath, "project/bin/" + os.path.basename(fromExeFile))
+        toExeFile = getPath(folder, "project/bin/" + os.path.basename(fromExeFile))
         if not os.path.exists(fromExeFile):
             exit("生成exe文件失败")
         remove(toExeFile)
@@ -125,15 +129,29 @@ def task_build(
 @app.command(
     help="格式化时间戳",
 )
-def timestamp(
-    value: Optional[float] = typer.Argument(None, help="时间戳，默认使用当前系统的时间戳", show_default=False),
+def timeshow(
+    timestamp: Optional[float] = typer.Argument(None, help="时间戳，默认使用当前系统的时间戳", show_default=False),
 ):
-    value = value or time.time()
+    timestamp = timestamp or time.time()
+    fmt = "%Y-%m-%d %H:%M:%S %z"
     print()
-    localtime = time.localtime(value)
+
+    print(timestamp)
+    print()
+    localtime = time.localtime(timestamp)
     tzname = time.tzname[(time.daylight and localtime.tm_isdst) and 1 or 0]
-    print(value)
+    printColor(time.strftime(fmt, localtime), tzname, colorList=[Fore.LIGHTYELLOW_EX])
     print()
-    print(tzname)
-    print(time.strftime("%Y-%m-%d %H:%M:%S", localtime))
+
+    tzNameList = [
+        "Asia/Tokyo",
+        "Asia/Kolkata",
+        "Europe/London",
+        "America/New_York",
+        "America/Los_Angeles",
+    ]
+    for tzName in tzNameList:
+        tz = pytz.timezone(tzName)
+        print(Datetime.fromtimestamp(timestamp, tz).strftime(fmt), tzName)
+
     print()
