@@ -2,10 +2,10 @@ import logging
 import os
 from typing import Any, TextIO
 
-from . import makeFolder
+from colorama import Fore
 
-from .print import (FOREGROUND_DARKPINK, FOREGROUND_DARKRED,
-                    FOREGROUND_DARKYELLOW, resetPrintColor, setPrintColor)
+from . import makeFolder
+from .print import resetPrintColor, setPrintColor
 
 _loggerName = 'beniutils'
 
@@ -47,15 +47,16 @@ def initLogger(loggerName: str = "", loggerLevel: int = logging.INFO, logFile: s
                 if record.levelno == logging.WARNING:
                     global _countWarning
                     _countWarning += 1
-                    setPrintColor(FOREGROUND_DARKYELLOW)
+                    setPrintColor(Fore.LIGHTYELLOW_EX)
+
                 elif record.levelno == logging.ERROR:
                     global _countError
                     _countError += 1
-                    setPrintColor(FOREGROUND_DARKRED)
+                    setPrintColor(Fore.LIGHTRED_EX)
                 elif record.levelno == logging.CRITICAL:
                     global _countCritical
                     _countCritical += 1
-                    setPrintColor(FOREGROUND_DARKPINK)
+                    setPrintColor(Fore.LIGHTMAGENTA_EX)
                 func(msg)
                 resetPrintColor()
                 self.flush()
