@@ -10,10 +10,11 @@ if not _isInited:
     init()
 
 
-def printColor(*values: Any, sep: str = " ", end: str = "\n", file: IO[str] = sys.stdout, flush: bool = False, color: list[Any] = []):
+def printColor(*values: Any, sep: str = " ", end: str = "\n", file: IO[str] = sys.stdout, flush: bool = False, colorList: list[Any] = []):
     '''color 数组参数 colorama.Fore / colorama.Back / colorama.Style 的常量'''
-    newValues = color + list(values) + [Style.RESET_ALL]
-    print(*newValues, sep=sep, end=end, file=file, flush=flush)
+    setPrintColor(*colorList)
+    print(*values, sep=sep, end=end, file=file, flush=flush)
+    resetPrintColor()
 
 
 def setPrintColor(*colorList: Any):
